@@ -20,7 +20,7 @@ from resotolib.baseresources import BaseResource, EdgeType
 from resotolib.config import Config
 from resotolib.core.actions import CoreFeedback
 from resotolib.core.model_export import node_to_dict
-from resotolib.json import from_json
+from resotolib.json import from_json, to_json
 from resotolib.proc import emergency_shutdown
 from resotolib.types import Json
 from rich import print as rich_print
@@ -33,6 +33,7 @@ from cloud2sql.analytics import AnalyticsEventSender
 from cloud2sql.arrow.config import ArrowOutputConfig
 from cloud2sql.show_progress import CollectInfo
 from cloud2sql.sql import SqlUpdater, sql_updater
+from cloud2sql.remote_graph import RemoteGraphCollector
 
 try:
     from cloud2sql.arrow.model import ArrowModel
@@ -45,6 +46,17 @@ except ImportError:
 log = getLogger("resoto.cloud2sql")
 
 
+def default_config() -> Json:
+    config: Config = Config  # type: ignore
+    for entry_point in pkg_resources.iter_entry_points("resoto.plugins"):
+        plugin_class = entry_point.load()
+        if issubclass(plugin_class, BaseCollectorPlugin):
+            plugin_class.add_config(config)
+
+    Config.init_default_config()
+    return to_json(Config.running_config.data)
+
+
 def collectors(raw_config: Json, feedback: CoreFeedback) -> Dict[str, BaseCollectorPlugin]:
     result = {}
     config: Config = Config  # type: ignore
@@ -54,10 +66,18 @@ def collectors(raw_config: Json, feedback: CoreFeedback) -> Dict[str, BaseCollec
             log.info(f"Found collector {plugin_class.cloud} ({plugin_class.__name__})")
             plugin_class.add_config(config)
             plugin = plugin_class()
-            if hasattr(plugin, "core_feedback"):
-                setattr(plugin, "core_feedback", feedback.with_context(plugin.cloud))
             result[plugin_class.cloud] = plugin
 
+    # lookup local plugins
+    if RemoteGraphCollector.cloud in raw_config:
+        log.info(f"Found collector {RemoteGraphCollector.cloud} ({RemoteGraphCollector.__name__})")
+        result[RemoteGraphCollector.cloud] = RemoteGraphCollector()
+        RemoteGraphCollector.add_config(config)
+
+    for plugin in result.values():
+        if hasattr(plugin, "core_feedback"):
+            setattr(plugin, "core_feedback", feedback.with_context(plugin.cloud))
+
     Config.init_default_config()
     Config.running_config.data = {**Config.running_config.data, **Config.read_config(raw_config)}
     return result
@@ -65,21 +85,21 @@ def collectors(raw_config: Json, feedback: CoreFeedback) -> Dict[str, BaseCollec
 
 def configure(path_to_config: Optional[str]) -> Json:
     # at least one key should be present
-    def require(keys: List[str], obj: Json, msg: str):
+    def require(keys: List[str], obj: Json, msg: str) -> None:
         if not (set(keys) & obj.keys()):
             raise ValueError(msg)
 
     config = {}
     if path_to_config:
         with open(path_to_config) as f:
-            config = yaml.safe_load(f)  # type: ignore
+            config = yaml.safe_load(f)
 
     if "sources" not in config:
         raise ValueError("No sources configured")
     if "destinations" not in config:
         raise ValueError("No destinations configured")
 
-    def validate_arrow_config(config: Json):
+    def validate_arrow_config(config: Json) -> None:
         require(["format"], config, "No format configured for arrow destination")
         if not config["format"] in ["parquet", "csv"]:
             raise ValueError("Format must be either parquet or csv")
@@ -149,7 +169,7 @@ def collect(
     if engine:
         return collect_sql(collector, engine, feedback, args)
     else:
-        if not set(["file", "s3", "gcs"]) & config["destinations"].keys():
+        if not {"file", "s3", "gcs"} & config["destinations"].keys():
             raise ValueError("No file destination configured")
         return collect_to_file(collector, feedback, config["destinations"]["arrow"])
 
@@ -191,7 +211,7 @@ def collect_to_file(
     # ingest the data
     writer = ArrowWriter(model, output_config)
     node: BaseResource
-    for node in sorted(collector.graph.nodes, key=lambda n: n.kind):
+    for node in sorted(collector.graph.nodes, key=lambda n: n.kind):  # type: ignore
         exported = prepare_node(node, collector)
         writer.insert_node(exported)
         ne_current += 1
